import logging
import sys

import click

from exit_codes import ExitCode
from .commands import run_file_ripper_once, run_file_ripper_continuously


@click.group()
def cli():
    pass


@cli.command("exec")
@click.argument("definitions_file", type=click.File("rt"))
@click.option("-fmt", "--format", "definitions_format", type=str, default="json")
@click.option("-ro", "--run-once", "run_once", is_flag=True, default=False)
@click.option("-ti", "--time-interval", "time_interval", type=int, default=5)
def handle_exec(definitions_file, definitions_format, run_once, time_interval):
    if run_once:
        run_file_ripper_once(definitions_file, definitions_format)
    else:
        run_file_ripper_continuously(definitions_file, definitions_format, time_interval)
    return ExitCode.OK


def main(argv=None):
    try:
        return cli(argv)
    except Exception as exc:
        logging.exception("Exception encountered running file-ripper", exc_info=exc)
        return ExitCode.SOFTWARE


if __name__ == "__main__":
    sys.exit(main())



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()
    setuptools.setup(
        name='file-ripper',
        version='1.3.5',
        author='Aaron Smith',
        author_email='asmitty92@gmail.com',
        license='MIT',
        long_description=long_description,
        long_description_content_type='text/markdown',
        packages=setuptools.find_packages('src'),
        package_dir={'': 'src'},
        install_requires=[
            "click",
            "dataclasses_json",
        ],
        entry_points={
            "console_scripts": [
                "file-ripper = file_ripper.cli:main"
            ]
        },
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3.7',
            'Programming Language :: Python :: 3.8',
            'Programming Language :: Python :: 3.9',
            'Programming Language :: Python :: 3.10',
            'Programming Language :: Python :: 3.11',
        ]
    )




FILE_TYPE = "file_type"
FILE_MASK = "file_mask"
DELIMITED = "DELIMITED"
FIXED = "FIXED"
XML = "XML"
DELIMITER = "delimiter"
HAS_HEADER = "has_header"
FIELD_DEFINITIONS = "field_definitions"
FIELD_NAME = "field_name"
START_POSITION = "start_position"
FIELD_LENGTH = "field_length"
RECORD_ELEMENT_NAME = "record_element_name"
XML_NODE_NAME = "xml_node_name"
INPUT_DIRECTORY = "input_directory"
COMPLETED_DIRECTORY = "completed_directory"
POSITION_IN_ROW = "position_in_row"
